@@ -20,17 +20,28 @@ LaF.  If not, see <http://www.gnu.org/licenses/>.
 #include "conversion.h"
 
 FactorColumn::FactorColumn(const Reader* reader, unsigned int column) :
-  Column(reader, column)
+  Column(reader, column), trim_(false)
 { }
 
 FactorColumn::~FactorColumn() {
 }
 
+void FactorColumn::set_trim(bool trim) {
+  trim_ = trim;
+}
+
+bool FactorColumn::get_trim() const {
+  return trim_;
+}
+    
 int FactorColumn::get_value() const {
   const char*  buffer = reader_->get_buffer(column_);
   unsigned int length = reader_->get_length(column_);
-  if (length == 0) return NA_INTEGER;
-  std::string value(buffer, length);
+  std::string value = chartostring(buffer, length, trim_);
+  if (value.length() == 0) return NA_INTEGER;
+  //if (length == 0 || all_chars_equal(buffer, length, ' ')) return NA_INTEGER;
+  //if (length == 0) return NA_INTEGER;
+  //std::string value(buffer, length);
   if (levels_[value] == 0) {
     levels_[value] = levels_.size();
   }
